@@ -6,6 +6,7 @@ from . import TreeNode
 
 
 def build_ListNode(val):
+    """ʹб"""
     if val is None:
         return None
     if isinstance(val, list):
@@ -21,6 +22,37 @@ def build_ListNode(val):
         return None
 
 
+def build_ListNode_with_skip(val, list1, list2, skip1, skip2):
+    """ཻ
+
+    :param val: Ͻֵ
+    :param list1: 1
+    :param list2: 2
+    :param skip1: 1λ
+    :param skip2: 2λ
+    :return:
+    """
+    head1 = build_ListNode(list1[0:skip1])
+    head2 = build_ListNode(list2[0:skip2])
+
+    if skip1 == len(list1) or skip2 == len(list2):
+        return head1, head2
+
+    head3 = build_ListNode(list1[skip1:])
+
+    i1 = head1
+    while i1.next:
+        i1 = i1.next
+    i1.next = head3
+
+    i2 = head2
+    while i2.next:
+        i2 = i2.next
+    i2.next = head3
+
+    return head1, head2
+
+
 def build_TreeNode(val):
     # ʹб
     if val is None:
